{% load cms_tags %}

<div class="alert
    {% if instance.context %} alert-{{ instance.context }}{% endif %}
    {% if instance.classes %} {{ instance.classes }}{% endif %}">

    {% if instance.icon %}
        {% with icon_class=instance.icon extra_css_classes="pull-left" %}{% include 'aldryn_bootstrap3/plugins/includes/icon.html' %}{% endwith %}
    {% endif %}

    {% for plugin in instance.child_plugin_instances %}
        {% render_plugin plugin %}
    {% endfor %}
</div>
