{% load cms_tags %}

<div class="well
    {% if instance.size %} well-{{ instance.size }}{% endif %}
    {% if instance.classes %} {{ instance.classes }}{% endif %}">

    {% for plugin in instance.child_plugin_instances %}
        {% render_plugin plugin %}
    {% endfor %}
</div>
